# Django settings for compte_agglo_montpellier project.

from portail_citoyen.settings import *

from log_handler import SysLogHandler

DEFAULT_FROM_EMAIL = 'e-services@montpellier-agglo.com'

INSTALLED_APPS += (
        'cmsplugin_text_wrapper',
        'feed_plugin',
        'compte_agglo_montpellier',
)

INSTALLED_APPS = tuple(app for app in INSTALLED_APPS if app != 'cms.plugins.text')

CMS_TEXT_WRAPPERS = (
    ('block', {
        'render_template': 'block.html',
        'extra_context':  {},
    }),
)

CMS_TEMPLATES = (
    ('base_two_columns.html', 'Deux colonnes'),
    ('base_one_column.html', 'Une colonne'),
)

TEMPLATE_DIRS = (os.path.join(os.path.dirname(__file__), 'templates'),) \
        + TEMPLATE_DIRS


LOGGING = {
    'version': 1,
    'disable_existing_loggers': True,
    'filters': {
        'require_debug_false': {
            '()': 'django.utils.log.RequireDebugFalse'
        }
    },
    'formatters': {
        'syslog': {
            'format': 'portail-citoyen(pid=%(process)d) %(name)s %(levelname)s %(message)s',
        },
    },
    'handlers': {
        'syslog': {
            'level':'DEBUG',
            'class':'compte_agglo_montpellier.log_handler.SysLogHandler', 
            'formatter': 'syslog',
            'facility': SysLogHandler.LOG_LOCAL0,
            'address': '/dev/log',
        },
        'mail_admins': {
            'level': 'ERROR',
            'filters': ['require_debug_false'],
            'class': 'django.utils.log.AdminEmailHandler'
        }
    },
    'loggers': {
        'authentic2': {
            'handlers': ['mail_admins','syslog'],
            'level': 'DEBUG',
            'propagate': False,
        },
        'portail_citoyen': {
            'handlers': ['mail_admins','syslog'],
            'level': 'DEBUG',
            'propagate': False,
        },
        'django': {
            'handlers': ['mail_admins','syslog'],
            'level': 'DEBUG',
            'propagate': False,
        },
        'requests': {
            'handlers': ['mail_admins','syslog'],
            'level': 'INFO',
            'propagate': False,
        },
        '': {
            'handlers': ['mail_admins','syslog'],
            'level': 'DEBUG',
            'propagate': True,
        },
    }
}

from django.conf.global_settings import PASSWORD_HASHERS

PASSWORD_HASHERS += (
    'authentic2.hashers.Drupal7PasswordHasher',
)

try:
    from local_settings import *
except ImportError:
    pass
