#! /usr/bin/env python

''' Setup script for Polynum
'''

from setuptools import setup, find_packages
from setuptools.command.install_lib import install_lib as _install_lib
from distutils.command.build import build as _build
from distutils.command.sdist import sdist  as _sdist
from distutils.cmd import Command
import glob

class compile_translations(Command):
    description = 'compile message catalogs to MO files via django compilemessages'
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        import os
        import sys
        from django.core.management.commands.compilemessages import \
            compile_messages
        for path in ['compte_agglo_montpellier'] + glob.glob('compte_agglo_montpellier/apps/*'):
            if not os.path.exists(os.path.join(path, 'locale')):
                continue
            curdir = os.getcwd()
            os.chdir(os.path.realpath(path))
            compile_messages(stderr=sys.stderr)
            os.chdir(curdir)

class build(_build):
    sub_commands = [('compile_translations', None)] + _build.sub_commands

class sdist(_sdist):
    sub_commands = [('compile_translations', None)] + _sdist.sub_commands

class install_lib(_install_lib):
    def run(self):
        self.run_command('compile_translations')
        _install_lib.run(self)


setup(name="compte-agglo-montpellier",
      version=0.1,
      license="AGPLv3 or later",
      description="Compte agglo montpellier",
      author="Entr'ouvert",
      author_email="info@entrouvert.org",
      maintainer="Benjamin Dauvergne",
      maintainer_email="info@entrouvert.com",
      include_package_data=True,
      package_data={
          '': [
               'templates/**.html',
               'templates/**.txt',
               'static/**.png',
               'static/**.gif',
               'static/**.css',
               'static/**.js',
               'locale/**.mo', 
               'fixtures/*.json',
              ]
      },
      packages=find_packages(),
      scripts=('compte-agglo-montpellier',),
      install_requires=[
            'portail-citoyen==0.1',
            'cmsplugin-embedded-menu==0.0.7',
            'cmsplugin-text-wrapper==0.5',
            'gunicorn',
      ],
      dependency_links = [
            'http://repos.entrouvert.org/portail-citoyen.git/snapshot/portail-citoyen-master.tar.gz#egg=portail-citoyen-0.1',
      ],
      cmdclass={'build': build, 'install_lib': install_lib,
          'compile_translations': compile_translations,
          'sdist': sdist},
)
